**mcgo**\
is an encryption project based on 
'[ГОСТ 28147-89](https://gist.github.com/empty-jack/2a6ddbe0d6852d74d16f617c11eda847/)'.
\
\
project include:\
_ encryption functions\
_ generation functions\
_ self compression functions